@echo off

rem last update was on June 27, 2014

REM The Vanilla Folders Archive batch file will automatically compress the folders with optimized textures in "Vanilla Optimized".
REM This step is done after the textures are optimized; details of the steps are in the DDSopt guide (http://wiki.step-project.com/Guide:DDSopt)
rem The archive file names are the same as the names of the folders in the Vanilla Optimized directory (e.g., STD_opt.7z) and have "_opt" added to each folder name.
REM If desired, the user can change these names after the optimization is completed.
REM For example, if a user prefers a single file with all of the HRDLC resources, the HRDLC1, HRDLC2, and HRDLC3 folders can be combined into a single folder prior to archiving.

REM The files are archived into non-solid 7zip archives.
rem The individual archive files are compressed at the root of the 7zip archive to avoid an additional unnecessary subdirectory in the archive.
REM LZMA2 compression is used, and multiple CPU cores are used for archiving if they are available.

rem When the optimization is complete the archives are moved to a "Vanilla Optimized Archive" directory.
REM From here they can be copied or moved to the installer directory used by a mod manager (Wrye Bash or Mod Organizer).


REM tests added 8/21/2013 to make sure the batch file is in the right folder and the folder structures are as expected
REM runtime added 8/22/2013

REM these 2 lines should ensure that the correct working directory is found
@setlocal enableextensions
@cd /d "%~dp0"

REM check directories to ensure the batch file and texture directories are in the right places
@echo off
echo.
echo The system says the Working Directory is   %cd%
echo This directory should include the "Vanilla Optimized" directory
echo If any of the above is incorrect terminate the processing and fix the problem
echo.


IF NOT EXIST "%cd%\Vanilla Optimized" echo Error: The Vanilla Optimized directory is not in the working directory; fix this before proceeding
echo.
pause


rem make sure directory exists for storing the archive files of optimized mods
IF NOT EXIST "%cd%\Vanilla Optimized Archive\NUL" MD "Vanilla Optimized Archive"


REM Get the starting time
set STARTTIME=%TIME%

@echo on

cd "Vanilla Optimized"
for /D %%d in (*.*) do "..\7za.exe" a -m0=lzma2  -mmt=4 -t7z  -ms=off "%%d.7z" ".\%%d\*" >nul

@echo off

rem now add _opt to the end of the file names of the optimized mods
ren *.7z ?????????????????????????????????????????????????????????????????????????????????????????_opt.7z

rem move the archived files to the proper directory
move *.7z "..\Vanilla Optimized Archive" >nul

rem change current directory so user can view the optimized and archived mods
cd "..\Vanilla Optimized Archive"



rem get time of completion
set ENDTIME=%TIME%



rem from http://stackoverflow.com/questions/9922498/calculate-time-difference-in-batch-file

rem Change formatting for the start and end times
for /F "tokens=1-4 delims=:.," %%a in ("%STARTTIME%") do (
    set /A "start=(((%%a*60)+1%%b %% 100)*60+1%%c %% 100)*100+1%%d %% 100"
)

for /F "tokens=1-4 delims=:.," %%a in ("%ENDTIME%") do (
    set /A "end=(((%%a*60)+1%%b %% 100)*60+1%%c %% 100)*100+1%%d %% 100"
)

rem Calculate the elapsed time by subtracting values
set /A elapsed=end-start

rem Format the results for output
set /A hh=elapsed/(60*60*100), rest=elapsed%%(60*60*100), mm=rest/(60*100), rest%%=60*100, ss=rest/100, cc=rest%%100
if %hh% lss 10 set hh=0%hh%
if %mm% lss 10 set mm=0%mm%
if %ss% lss 10 set ss=0%ss%
if %cc% lss 10 set cc=0%cc%

set DURATION=%hh%:%mm%:%ss%,%cc%

echo.
echo.
echo Start    : %STARTTIME%
echo Finish   : %ENDTIME%
echo          ---------------
echo Duration : %DURATION%
	
pause

